/*
This file is a `shader header' which contains all of the shader parameters which
are commonly used by multiple shaders, such as viewing transformation matrices.

Created by: John Kloetzli
Created on: 9/26/2007
*/

#define PI 3.14159

//Spherical harmonic normaliation values
#define norm0 (1.0/(2.0*sqrt(PI)))
#define norm1 (sqrt(3.0)/(2.0*sqrt(PI)))
#define norm2 (sqrt(15)/(2.0*sqrt(PI)))
#define norm3 (sqrt(5)/(4.0*sqrt(PI)))

float4   g_fTime;                   // App's time in seconds
float4x4 g_mWorldViewProjection;    // WVP matrix
float4x4 g_mInvWorldViewProjection;	// Inverse WVP
float4x4 g_mInvViewProjection;		// Inverse VP
float4x4 g_mInvTransWorld;			// Inverse Transpose world matrix for normal transforming

//Spherical harmonic coefficients for the environment
float4 g_SHEnvironment0;
float4 g_SHEnvironment1;
float4 g_SHEnvironment2;
float4 g_SHEnvironment3;
float4 g_SHEnvironment4;
float4 g_SHEnvironment5;
float4 g_SHEnvironment6;
float4 g_SHEnvironment7;
float4 g_SHEnvironment8;

//Function to compute diffuse lighting based upon the environment SH coefs and normal dirn
float3 ComputeLighting( float3 Normal )
{
	Normal.xyz = normalize( -Normal.yxz );
	float3 color = 
		  norm0 * g_SHEnvironment0.xyz
		+ norm1 * g_SHEnvironment1.xyz * Normal.x
		+ norm1 * g_SHEnvironment2.xyz * Normal.z
		+ norm1 * g_SHEnvironment3.xyz * Normal.y
		+ norm2 * g_SHEnvironment4.xyz * (Normal.x*Normal.y)
		+ norm2 * g_SHEnvironment5.xyz * (Normal.y*Normal.z)
		+ norm3 * g_SHEnvironment6.xyz * (3.0*Normal.z*Normal.z - 1.0)
		+ norm2 * g_SHEnvironment7.xyz * (Normal.x*Normal.z)
		+ norm2 * g_SHEnvironment8.xyz * (Normal.x*Normal.x - Normal.y*Normal.y);
		
	return 5.0*saturate( .1*color );
}