//--------------------------------------------------------------------------------------
// Shaders for the sphere demo.
//--------------------------------------------------------------------------------------

//Include common values
#include "parameters.fxh"

//The light direction of the sun
float3 g_v3LightDir;

//--------------------------------------------------------------------------------------
// Vertex shader output structure
//--------------------------------------------------------------------------------------
struct VS_OUTPUT
{
    float4 Position		: POSITION;   // vertex position 
    float2 WorldPos		: TEXCOORD0;  // vertex texture coords
    float3 Normal		: TEXCOORD1;
};


//--------------------------------------------------------------------------------------
// This shader computes standard transform and lighting
//--------------------------------------------------------------------------------------
VS_OUTPUT RenderSceneVS( float4 vPos		: POSITION,
						float3 vNormal		: NORMAL )
{
    VS_OUTPUT Output;
    float3 vNormalWorldSpace;
    
    // Transform the position from object space to homogeneous projection space
    Output.Position = mul(vPos, g_mWorldViewProjection);
    
    //Push the normal forward into world space
    Output.Normal = mul(vNormal, g_mInvTransWorld);
    
    Output.WorldPos = vPos;
    
    return Output;    
}

//--------------------------------------------------------------------------------------
// This shader outputs the pixel's color by modulating the texture's
//       color with diffuse material color
//--------------------------------------------------------------------------------------
float4 RenderScenePS( VS_OUTPUT In ) :COLOR0
{	
	//Diffuse lighting component is based upon the SH coefficients
	float3 Diffuse = .6*dot(normalize(g_v3LightDir),normalize(In.Normal));
    
    //Ambient light component is not fancy
	float3 Ambient = float3(.3,.3,.3);

    return float4( Ambient + Diffuse, 1);
}

//--------------------------------------------------------------------------------------
// Renders scene to render target
//--------------------------------------------------------------------------------------
technique RenderDiffuse
{
    pass P0
    {          
        VertexShader = compile vs_3_0 RenderSceneVS();
        PixelShader  = compile ps_3_0 RenderScenePS();
    }
}
